@@ -1,14 +1,12 @@
-from learning_loop_node.status import Status
+from learning_loop_node.status import Status, State
 from fastapi import FastAPI
 import socketio
 import asyncio
-from status import State
 import asyncio
-import requests
 import os
 from icecream import ic
 
-SERVER_BASE_URL_DEFAULT = 'http://backend'
+
 WEBSOCKET_BASE_URL_DEFAULT = 'ws://backend'
 BASE_PROJECT = 'demo'
 BASE_ORGANIZATION = 'zauberzeug'
@@ -20,24 +18,15 @@ class Node(FastAPI):
 
     def __init__(self, name: str, uuid: str):
         super().__init__()
-        self.url = os.environ.get('SERVER_BASE_URL', SERVER_BASE_URL_DEFAULT)
         self.ws_url = os.environ.get('WEBSOCKET_BASE_URL', WEBSOCKET_BASE_URL_DEFAULT)
         self.username = os.environ.get('USERNAME', None)
         self.password = os.environ.get('PASSWORD', None)
-        self.project = os.environ.get('PROJECT', BASE_PROJECT)
         self.organization = os.environ.get('ORGANIZATION', BASE_ORGANIZATION)
-        self.db_user = os.environ.get('DBNAME', None)
-        self.db_pw = os.environ.get('DBPW', None)
-        self.headers = {}
+        self.project = os.environ.get('PROJECT', BASE_PROJECT)
 
         self.name = name
         self.uuid = uuid
 
-        if self.username:
-            import base64
-            self.headers["Authorization"] = "Basic " + \
-                base64.b64encode(f"{self.username}:{self.password}".encode()).decode()
-
         self.sio = socketio.AsyncClient(
             reconnection_delay=0,
             request_timeout=0.5,
@@ -80,7 +69,7 @@ class Node(FastAPI):
 
         print('connecting to Learning Loop', flush=True)
         try:
-            await self.sio.connect(f"{self.ws_url}", auth={'username': self.db_user, 'password': self.db_pw}, headers=self.headers, socketio_path="/ws/socket.io")
+            await self.sio.connect(f"{self.ws_url}", auth={'username': self.username, 'password': self.password}, socketio_path="/ws/socket.io")
             print('my sid is', self.sio.sid, flush=True)
             print('connected to Learning Loop', flush=True)
         except socketio.exceptions.ConnectionError as e:
